@@ -33,7 +33,11 @@ int main(int argc, char **argv)
 {
 	if (!gpe_application_init(&argc, &argv))
 		exit(1);
-        
+
+	bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
+	textdomain(PACKAGE);
+	
 	gtk_rc_parse(DATAPATH(gtkrc));
 	
 	init_main_window();
@@ -194,6 +198,7 @@ static void init_main_window(void)
 
 	g_signal_connect(G_OBJECT(window.toplevel), "configure-event",
 			 G_CALLBACK(resize_callback), NULL);
+	
 }
 
 static void load_modules(void)
@@ -333,9 +338,6 @@ struct myscroll * myscroll_new(gboolean continuous)
 	g_signal_connect(G_OBJECT(scroll->draw), "expose-event",  
 			 G_CALLBACK(myscroll_draw_cb), scroll);
 	
-	g_signal_connect(G_OBJECT(scroll->draw), "configure-event",
-			 G_CALLBACK(myscroll_size_cb), scroll);
-	
 	if (continuous)
 		g_signal_connect(G_OBJECT(scroll->adjust), "value-changed",
 				 G_CALLBACK(myscroll_adjust_cb), scroll->draw);
